@@ -4,12 +4,11 @@ use 5.006;
 use strict;
 use Sys::Hostname;
 use IO::Select;
-use IO::Handle;
 use Carp;
 
 use constant HOSTNAME => hostname();
 
-$Net::Server::Mail::VERSION = '0.19_02';
+$Net::Server::Mail::VERSION = '0.01';
 
 =pod
 
@@ -30,8 +29,7 @@ Net::Server::Mail - Class to easily create a mail server
         my $smtp = new Net::Server::Mail::SMTP socket => $conn;
         $smtp->set_callback(RCPT => \&validate_recipient);
         $smtp->set_callback(DATA => \&queue_message);
-        $smtp->process();
-	$conn->close();
+        $smtp->process;
     }
 
     sub validate_recipient
@@ -48,7 +46,7 @@ Net::Server::Mail - Class to easily create a mail server
         {
             return(0, 513, 'Syntax error.');
         }
-        elsif(not(grep $domain eq $_, @local_domains))
+        elsif(grep $domain eq $_, @local_domains)
         {
             return(0, 554, "$recipient: Recipient address rejected: Relay access denied");
         }
@@ -74,25 +72,10 @@ Net::Server::Mail - Class to easily create a mail server
 
 =head1 DESCRIPTION
 
-This module is a versatile and extensible implementation of the SMTP
-protocol and its different evolutions like ESMTP and LMTP. The event
-driven object-oriented API makes easy to incorporate the SMTP protocol
-to your programs.
-
-Other SMTPd implementations don't support useful ESMTP extensions and
-the LMTP protocol. Their interface design precludes adding them
-later. So I've decided to rewrite a complete implementation with
-extensibility in mind.
-
-It provides mechanism to easy addition future or not yet implemented
-ESMTP extensions. Developers can hook code at each SMTP session state
-and change the module's behaviors by registering event call-backs. The
-class is designed to be easily inherited from.
-
-This class is the base class for mail service protocols such axs
+This class is the base class for mail service protocols such as
 B<Net::Server::Mail::SMTP>, B<Net::Server::Mail::ESMTP> and
-B<Net::Server::Mail::LMTP>. Refer to the documentation provided with
-each of these modules.
+B<Net::Server::Mail::LMTP>. Refer to the documentation provided
+with each of these modules.
 
 =head1 METHODS
 
@@ -162,24 +145,8 @@ sub init
 
     if(defined $options->{handle_in} && defined $options->{handle_out})
     {
-        if(UNIVERSAL::isa($options->{handle_in},'IO::Handle'))
-        {
-            $self->{in} = $options->{handle_in};
-        }
-        else
-        {
-            $self->{in} = 
-              IO::Handle->new->fdopen(fileno($options->{handle_in}), "r");
-        }
-        if(UNIVERSAL::isa($options->{handle_out},'IO::Handle'))
-        {
-            $self->{out} = $options->{handle_out};
-        }
-        else
-        {
-            $self->{out} = 
-              IO::Handle->new->fdopen(fileno($options->{handle_out}), "w");
-        }
+        $self->{in}  = $options->{handle_in};
+        $self->{out} = $options->{handle_out};
     }
     elsif(defined $options->{'socket'})
     {
@@ -188,11 +155,10 @@ sub init
     }
     else
     {
-        $self->{in}  = IO::Handle->new->fdopen(fileno(STDIN), "r");
-        $self->{out} = IO::Handle->new->fdopen(fileno(STDOUT), "w");
+        $self->{in}  = \*STDIN;
+        $self->{out} = \*STDOUT;
     }
 
-    $self->{out}->autoflush(1);
     $self->{process_operation} = \&process_operation;
 
     return $self;
@@ -203,8 +169,7 @@ sub init
 =head2 dojob
 
 Some command need to do some job after the handler call. Handler may
-want to overide this comportement to prevent from this job being
-executed.
+want to overide this comportement an avoid this job to be executed.
 
 By calling this method with a (defined) false value as argument,
 expected job isn't executed. Defaults to true.
@@ -290,7 +255,7 @@ sub make_event
         }
     }
 
-    die "return code `$code' isn't numeric" if($code =~ /\D/);
+    die "recturn code `$code' isn't numeric" if($code =~ /\D/);
 
     $self->handle_reply($name, $success, $code, $msg)
       if defined $code and length $code;
@@ -465,75 +430,20 @@ sub process
     $self->banner;
     # switch to non-blocking socket to handle PIPELINING
     # ESMTP extension. See RFC 2920 for more details.
-    if($^O eq 'MSWin32')
+    $in->blocking(0);
+    while($sel->can_read($self->{options}->{idle_timeout} || undef))
     {
-        # win32 platforms don't support nonblocking IO
-        ioctl($in, 2147772030, 1);
-    }
-    else
-    {
-        defined($in->blocking(0)) or die "Couldn't set nonblocking: $^E";
-    }
-    
-    my $buffer = ""; 
-    while (1) {
-        # wait for data and read it
-        my $rv = undef;
-
-        if ($sel->can_read($self->{options}->{idle_timeout} || undef))
+        $_ = join '', <$in>;
+        if(defined $self->next_input_to())
         {
-            if ($^O eq 'MSWin32')
-            {
-                # see how much data is available to read
-                my $size = pack("L",0);
-                ioctl($in, 1074030207, $size);
-                $size = unpack("L", $size);
-
-                # read the data to $buffer
-                $rv = sysread($in, $buffer, $size, length($buffer));
-            }
-            else
-            {
-                $rv = sysread($in, $buffer, 512*1024, length($buffer));
-            }
+            $self->tell_next_input_method($_);
         }
-        if ((not defined $rv) or ($rv == 0)) {
-            # timeout, read error or connection closed
-            last;
-        }
-
-        # process all terminated lines
-        # Note: Should accept only CRLF according to RFC. We accept
-        # plain LFs anyway because its more liberal and works as well.
-        my $newline_idx = rindex($buffer, "\n");
-        if ($newline_idx >= 0) {
-            # one or more lines, terminated with \r?\n
-            my $chunk = substr($buffer, 0, $newline_idx+1);
-            # remaining buffer
-            $buffer = substr($buffer, $newline_idx+1);
-
-            my $rv;
-            if(defined $self->next_input_to())
-            {
-                $rv = $self->tell_next_input_method($chunk);
-            }
-            else
-            {
-                $rv = $self->{process_operation}($self, $chunk);
-            }
+        else
+        {
+            next unless defined;
+            my $rv = $self->{process_operation}($self, $_);
             # if $rv is defined, we have to close the connection
-            if (defined $rv) {
-                return $rv;
-            }
-        }
-
-        # limit the size of lines to protect from excessive memory consumption
-        # (RFC specifies 1000 bytes including \r\n)
-        if (length($buffer) > 1000) {
-            $self->make_event(
-                name => 'linetobig',
-                success_reply => [552, 'line too long' ]);
-            return 1;
+            return $rv if defined $rv;
         }
     }
 
@@ -557,13 +467,6 @@ sub process_operation
 {
     my($self, $operation) = @_;
     my($verb, $params) = $self->tokenize_command($operation);
-    if(defined $params && $params =~ /[\r\n]/)
-    {
-        # doesn't support grouping of operations
-        $self->reply(453, "Command received prior to completion of".
-                     " previous command sequence");
-        return;
-    }
     $self->process_command($verb, $params);
 }
 
@@ -738,19 +641,26 @@ Olivier Poitrey E<lt>rs@rhapsodyk.netE<gt>
 
 =head1 AVAILABILITY
 
-Available on CPAN.
+The official FTP location is:
 
-anonymous Git repository:
+B<ftp://ftp.rhapsodyk.net/pub/devel/perl/Net-Server-Mail/>
 
-git clone git://github.com/rs/net-server-mail.git
+Also available on CPAN.
 
-Git repository on the web:
+anonymous CVS repository:
 
-L<https://github.com/rs/net-server-mail>
+CVS_RSH=ssh cvs -d anonymous@cvs.rhapsodyk.net:/devel co
+Net-Server-Mail
+
+(supply an empty string as password)
+
+CVS repository on the web:
+
+http://www.rhapsodyk.net/cgi-bin/cvsweb/Net-Server-Mail/
 
 =head1 BUGS
 
-Please use CPAN system to report a bug (http://rt.cpan.org/).
+Please send bug-reports to rs-bugs@rhapsodyk.net.
 
 =head1 LICENCE
 
@@ -771,13 +681,7 @@ USA
 
 =head1 COPYRIGHT
 
-=over
-
-=item Copyright (C) 2002 - Olivier Poitrey
-
-=item Copyright (C) 2007-2013 - Xavier Guimard
-
-=item Copyright (C) 2012 - Georg Hoesch
+Copyright (C) 2002 - Olivier Poitrey
 
 =cut
 
