@@ -5,8 +5,6 @@ use strict;
 use Carp;
 use base qw(Net::Server::Mail::SMTP);
 
-our $VERSION = "0.16";
-
 =pod
 
 =head1 NAME
@@ -23,15 +21,14 @@ Net::Server::Mail::ESMTP - A module to implement the ESMTP protocole
     my $conn;
     while($conn = $server->accept)
     {
-        my $esmtp = new Net::Server::Mail::ESMTP socket => $conn;
+        my $esmtp = new Net::Server::Mail::SMTP socket => $conn;
         # activate some extensions
         $esmtp->register('Net::Server::Mail::ESMTP::8BITMIME');
         $esmtp->register('Net::Server::Mail::ESMTP::PIPELINING');
         # adding some handlers
         $esmtp->set_callback(RCPT => \&validate_recipient);
         $esmtp->set_callback(DATA => \&queue_message);
-        $esmtp->process();
-	$conn->close()
+        $esmtp->process;
     }
 
     sub validate_recipient
@@ -48,7 +45,7 @@ Net::Server::Mail::ESMTP - A module to implement the ESMTP protocole
         {
             return(0, 513, 'Syntax error.');
         }
-        elsif(not(grep $domain eq $_, @local_domains))
+        elsif(grep $domain eq $_, @local_domains)
         {
             return(0, 554, "$recipient: Recipient address rejected: Relay access denied");
         }
@@ -66,7 +63,7 @@ Net::Server::Mail::ESMTP - A module to implement the ESMTP protocole
         return(0, 554, 'Error: no valid recipients')
             unless(@recipients);
 
-        my $msgid = add_queue($sender, \@recipients, $data)
+        my $msgid = add_queue($sender, \@recipients, $data);
           or return(0);
 
         return(1, 250, "message queued $msgid");
@@ -169,19 +166,6 @@ sub sub_reply
     push(@{$self->{xreply}->{$verb}}, $code);
 }
 
-sub extend_mode
-{
-    my($self, $mode) = @_;
-    $self->{extend_mode} = $mode;
-    for my $extend (@{$self->{extensions}})
-    {
-        if($extend->can('extend_mode'))
-        {
-            $extend->extend_mode($mode);
-        }
-    }
-}
-
 =pod
 
 =head1 EVENTS
@@ -228,7 +212,6 @@ sub ehlo
         push(@extends, join(' ', $extend->keyword, $extend->parameter));
     }
 
-    $self->extend_mode(1);
     $self->make_event
     (
         name => 'EHLO',
@@ -237,6 +220,7 @@ sub ehlo
         {
             # according to the RFC, EHLO ensures "that both the SMTP client
             # and the SMTP server are in the initial state"
+            $self->{extend_mode} = 1;
             $self->step_reverse_path(1);
             $self->step_forward_path(0);
             $self->step_maildata_path(0);
@@ -254,6 +238,13 @@ sub helo
     $self->SUPER::helo($hostname);
 }
 
+sub rset
+{
+    my($self) = @_;
+    $self->{extend_mode} = 0;
+    $self->SUPER::rset();
+}
+
 sub handle_options
 {
     my($self, $verb, $address, @options) = @_;
@@ -270,7 +261,6 @@ sub handle_options
         my $handler = $self->{xoption}->{$verb}->{$key};
         if(defined $handler)
         {
-            no strict "refs";
             &$handler($self, $verb, $address, $key, $value);
         }
         else
@@ -311,19 +301,26 @@ Olivier Poitrey E<lt>rs@rhapsodyk.netE<gt>
 
 =head1 AVAILABILITY
 
-Available on CPAN.
+The official FTP location is:
 
-anonymous Git repository:
+B<ftp://ftp.rhapsodyk.net/pub/devel/perl/Net-Server-Mail/>
 
-git clone git://github.com/rs/net-server-mail.git
+Also available on CPAN.
 
-Git repository on the web:
+anonymous CVS repository:
 
-L<https://github.com/rs/net-server-mail>
+CVS_RSH=ssh cvs -d anonymous@cvs.rhapsodyk.net:/devel co
+Net-Server-Mail
+
+(supply an empty string as password)
+
+CVS repository on the web:
+
+http://www.rhapsodyk.net/cgi-bin/cvsweb/Net-Server-Mail/
 
 =head1 BUGS
 
-Please use CPAN system to report a bug (http://rt.cpan.org/).
+Please send bug-reports to rs-bugs@rhapsodyk.net.
 
 =head1 LICENCE
 
@@ -344,7 +341,7 @@ USA
 
 =head1 COPYRIGHT
 
-Copyright (C) 2002 - Olivier Poitrey, 2007 - Xavier Guimard
+Copyright (C) 2002 - Olivier Poitrey
 
 =cut
 
