@@ -4,8 +4,6 @@ use 5.006;
 use strict;
 use base 'Net::Server::Mail';
 
-our $VERSION = "0.18";
-
 =pod
 
 =head1 NAME
@@ -25,8 +23,7 @@ Net::Server::Mail::SMTP - A module to implement the SMTP protocole
         my $smtp = new Net::Server::Mail::SMTP socket => $conn;
         $smtp->set_callback(RCPT => \&validate_recipient);
         $smtp->set_callback(DATA => \&queue_message);
-        $smtp->process();
-        $conn->close()
+        $smtp->process;
     }
 
     sub validate_recipient
@@ -43,7 +40,7 @@ Net::Server::Mail::SMTP - A module to implement the SMTP protocole
         {
             return(0, 513, 'Syntax error.');
         }
-        elsif(not(grep $domain eq $_, @local_domains))
+        elsif(grep $domain eq $_, @local_domains)
         {
             return(0, 554, "$recipient: Recipient address rejected: Relay access denied");
         }
@@ -61,7 +58,7 @@ Net::Server::Mail::SMTP - A module to implement the SMTP protocole
         return(0, 554, 'Error: no valid recipients')
             unless(@recipients);
 
-        my $msgid = add_queue($sender, \@recipients, $data)
+        my $msgid = add_queue($sender, \@recipients, $data);
           or return(0);
 
         return(1, 250, "message queued $msgid");
@@ -89,7 +86,7 @@ sub init
     return $rv unless $rv eq $self;
 
     $self->def_verb(HELO => 'helo');
-    $self->def_verb(VRFY => 'vrfy');
+    $self->def_verb(VEFY => 'vrfy');
     $self->def_verb(EXPN => 'expn');
     $self->def_verb(TURN => 'turn');
     $self->def_verb(HELP => 'help');
@@ -108,9 +105,6 @@ sub init
     $self->step_forward_path(0);
     $self->step_maildata_path(0);
 
-    # handle data after the end of data indicator (.)
-    $self->{data_handle_more_data} = 0;
-
     return $self;
 }
 
@@ -384,14 +378,7 @@ sub mail
         return;
     }
 
-    my($address, $rest, @options);
-    unless (($address, $rest) = $args =~ /^<(.*?)>(?: (\S.*))?$/) {
-        $self->reply(501, 'Syntax error in parameters or arguments');
-        return;
-    }
-    if ($rest) {
-        @options = split ' ', $rest;
-    }
+    my($address, @options) = split(' ', $args);
 
     unless($self->handle_options('MAIL', $address, @options))
     {
@@ -420,7 +407,7 @@ sub mail
 
 Handler takes address as argument. On success, engage the mail data path step and
 push the given address into the recipient list for later use (get it
-with get_recipients() method).
+with get_recipient() method).
 
 =cut
 
@@ -440,14 +427,7 @@ sub rcpt
         return;
     }
 
-    my($address, $rest, @options);
-    unless (($address, $rest) = $args =~ /^<(.*?)>(?: (\S.*))?$/) {
-        $self->reply(501, 'Syntax error in parameters or arguments');
-        return;
-    }
-    if ($rest) {
-        @options = split ' ', $rest;
-    }
+    my($address, @options) = split(' ', $args);
 
     unless($self->handle_options('RCPT', $address, @options))
     {
@@ -576,7 +556,6 @@ sub data
         return;
     }
 
-    $self->{last_chunk} = '';
     $self->make_event
       (
        name => 'DATA-INIT',
@@ -587,46 +566,21 @@ sub data
     return;
 }
 
-# Because data is cutted into pieces (4096 bytes), we have to search
-# "\r\n.\r\n" sequence in 2 consecutive pieces. $self->{last_chunk}
-# contains the last 5 bytes.
 sub data_part
 {
     my($self, $data) = @_;
 
-    # search for end of data indicator
-    $data ||= '';
-    if("$self->{last_chunk}$data" =~ /\r?\n\.\r?\n/s )
-    {
-        my $more_data = $';
-        if(length $more_data)
-        {
-            # Client sent a command after the end of data indicator ".".
-            if(!$self->{data_handle_more_data})
-            {
-                $self->reply(453, "Command received prior to completion of".
-                                  " previous command sequence");
-                return;
-            }
-        }
-        
-        # RFC 821 compliance.
-        ($data = "$self->{last_chunk}$data") =~ s/(\r?\n)\.\r?\n(QUIT\r?\n)?$/$1/s;
-        $self->{_data} .= $data;
-        # RFC 2821 by the letter
-        $self->{_data} =~ s/^\.(.+\015\012)(?!\n)/$1/gm;
-        return $self->data_finished($more_data);
-    }
+    return $self->data_finished()
+      if($data =~ /^\.\r?\n$/m);
 
-    my $tmp = $self->{last_chunk};
-    $self->{last_chunk} = substr $data, -5;
-    $data = $tmp . ($data ? substr ($data, 0, -5) : '');
     $self->make_event
       (
        name => 'DATA-PART',
        arguments => [\$data],
        on_success => sub
        {
+           # RFC 821 compliance.
+           $data =~ s/^\.//mg;
            $self->{_data} .= $data;
            # please, recall me soon !
            $self->next_input_to(\&data_part);
@@ -639,7 +593,7 @@ sub data_part
 
 sub data_finished
 {
-    my($self, $more_data) = @_;
+    my($self) = @_;
 
     $self->make_event
     (
@@ -648,20 +602,7 @@ sub data_finished
         success_reply => [250, 'message sent'],
     );
 
-    # reinitiate the connection
-    $self->step_reverse_path(1);
-    $self->step_forward_path(0);
-    $self->step_maildata_path(0);
-
-    # if more data, handle it
-    if($more_data)
-    {
-        return $self->{process_operation}($self, $more_data);
-    }
-    else
-    {
-        return;
-    }
+    return;
 }
 
 =pod
@@ -684,8 +625,7 @@ sub rset
         name => 'RSET',
         on_success => sub
         {
-            $self->step_reverse_path(1)
-              if($self->step_reverse_path());
+            $self->step_reverse_path(0);
             $self->step_forward_path(0);
             $self->step_maildata_path(0);
         },
@@ -749,19 +689,26 @@ Olivier Poitrey E<lt>rs@rhapsodyk.netE<gt>
 
 =head1 AVAILABILITY
 
-Available on CPAN.
+The official FTP location is:
 
-anonymous Git repository:
+B<ftp://ftp.rhapsodyk.net/pub/devel/perl/Net-Server-Mail/>
 
-git clone git://github.com/rs/net-server-mail.git
+Also available on CPAN.
 
-Git repository on the web:
+anonymous CVS repository:
 
-L<https://github.com/rs/net-server-mail>
+CVS_RSH=ssh cvs -d anonymous@cvs.rhapsodyk.net:/devel co
+Net-Server-Mail
+
+(supply an empty string as password)
+
+CVS repository on the web:
+
+http://www.rhapsodyk.net/cgi-bin/cvsweb/Net-Server-Mail/
 
 =head1 BUGS
 
-Please use CPAN system to report a bug (http://rt.cpan.org/).
+Please send bug-reports to rs-bugs@rhapsodyk.net.
 
 =head1 LICENCE
 
@@ -782,11 +729,7 @@ USA
 
 =head1 COPYRIGHT
 
-<<<<<<< HEAD:lib/Net/Server/Mail/SMTP.pm
 Copyright (C) 2002 - Olivier Poitrey
-=======
-Copyright (C) 2002 - Olivier Poitrey, 2007 - Xavier Guimard
->>>>>>> new/master:lib/Net/Server/Mail/SMTP.pm
 
 =cut
 
